@@ -1,6 +1,6 @@
 
 #%%
-from DataLoader import reports
+from DataLoader import consus, reports
 from abc import ABC,abstractmethod
 from . import daily,status,reports
 from .config import provider_config
@@ -220,6 +220,60 @@ class LocalPorvider(BaseProvider):
             fields: preclose open high low close change pctchange volume amount
         """
         return TDP.get_daily_aswsindexeod(instruments,fields,start_date,end_date)
+
+    def daily_barra_dly_specret(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: "CNE5S_100_Asset_DlySpecRet"
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_daily_dly_specret(instruments,fields,start_date,end_date)
+
+    def daily_barra_dly_prices(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5_Daily_Asset_Price'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_daily_dly_prices(instruments,fields,start_date,end_date)
+
+    def daily_barra_rates(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_Rates'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_daily_rates(instruments,fields,start_date,end_date)
+
+    def daily_barra_ashare_exposure(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_100_Asset_Exposure'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_daily_ashare_exposure(instruments,fields,start_date,end_date)
+
+    def daily_barra_fact_cov(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_100_Covariance'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_daily_ashare_faccov(instruments,fields,start_date,end_date)
+
+    def daily_barra_fact_ret(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_100_DlyFacRet'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: return
+        """
+        return TDP.get_daily_factorRet(instruments,fields,start_date,end_date)
     
     def daily_indexweight(self,instruments,**kws):
         """
@@ -436,12 +490,57 @@ class LocalPorvider(BaseProvider):
             fields : ...
         """
         return FRP.repo_issuedate_pre(instruments,fields,**kws)
-
     
+    def repo_fanc_indicator(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareFinancialIndicator'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_issuedate_pre(instruments,fields,**kws)
+
+    def consus(self,instruments,fields = None,foreward_type = 'fy1',window_days = '30d',**kws):
+        """
+            table_name: 'AShareConsensusData'
+            input:instruments:List(str),fields:List(str)
+                  foreward_type: fy0, fy1, fy2, fy3
+                  window_days: 30d,90d,180d,180l
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.consus(instruments,fields,foreward_type,window_days,**kws)
+    
+
+    def consus_rolling(self,instruments,fields = None,foreward_type = 'fy1',**kws):
+        """
+            table_name: 'AShareConsensusRollingData'
+            input:instruments:List(str),fields:List(str)
+                  foreward_type: cagr, fy0, fy1, fy2, fy3 , yoy , yoy2
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.consus_rolling(instruments,fields,foreward_type,**kws)
+
+    def stk_rating(self,instruments,fields = None,window_days = 'fy1',**kws):
+        """
+            table_name: 'AShareStockRatingConsus'
+            input:instruments:List(str),fields:List(str)
+                  window_days: 30d,90d,180d
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.stk_rating(instruments,fields,window_days,**kws)
+        
 
 TDP = getattr(daily,provider_config["TDP"])()
 IdxSP = getattr(status,provider_config["IdxSP"])()
 InstSP = getattr(status,provider_config["InstSP"])()
 InduSP = getattr(status,provider_config["InduSP"])()
 FRP = getattr(reports,provider_config["FRP"])()
+CDP = getattr(consus,provider_config["CDP"])()
 BP = eval(provider_config["BP"])()  
