@@ -18,6 +18,7 @@ ashare_profit_noti = os.path.join(data_path,r'AShareProfitNotice')
 ashare_ttmhis = os.path.join(data_path,r'AShareTTMHis')
 ashare_holdernumber = os.path.join(data_path,r'AShareHolderNumber')
 ashare_issuedate_pre = os.path.join(data_path,r'AShareIssuingDatePredict')
+ashare_fanc_indicator = os.path.join(data_path,r'AShareFinancialIndicator')
 
 class BaseFincReportsProvider(abc.ABC):
 
@@ -97,3 +98,8 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
     def repo_issuedate_pre(self,instruments,fields,**kws):
         return self.get_repo_data(ashare_issuedate_pre,instruments,fields,**kws) 
 
+    @print_func_time
+    def repo_fanc_indicator(self,instruments,fields,**kws):
+        return self.get_repo_data(ashare_fanc_indicator,instruments,fields,**kws)
+        
+
